@@ -160,7 +160,7 @@ install_go() {
     rm -rf /usr/local/go /usr/local/go1.8 /usr/local/go1.9
     mv go1.9 /usr/local/
     ln -s /usr/local/go1.9 /usr/local/go
-    GO_VERSION=1.21.1
+    GO_VERSION=1.21.5
     wget --progress=dot:giga https://dl.google.com/go/go${GO_VERSION}.linux-amd64.tar.gz -O /tmp/golang.tar.gz
     tar -C /usr/local -xzf /tmp/golang.tar.gz
     update-alternatives --install "/usr/bin/go" "go" "/usr/local/go/bin/go" 0
@@ -233,7 +233,7 @@ install_deps() {
               sleep 1
           done
       fi
-      if [ $DEBIAN_VERSION = bionic -o $DEBIAN_VERSION = focal -o $DEBIAN_VERSION = bullseye -o $DEBIAN_VERSION = buster -o $DEBIAN_VERSION = xenial -o $DEBIAN_VERSION = jammy ]; then
+      if [ $DEBIAN_VERSION = bionic -o $DEBIAN_VERSION = focal -o $DEBIAN_VERSION = bullseye -o $DEBIAN_VERSION = buster -o $DEBIAN_VERSION = bookworm -o $DEBIAN_VERSION = jammy -o $DEBIAN_VERSION = xenial ]; then
           until apt-get update; do
               echo "waiting"
               sleep 1
@@ -370,12 +370,6 @@ build_rpm(){
     rm -fr rpmbuild
     mkdir -vp rpmbuild/{SOURCES,SPECS,BUILD,SRPMS,RPMS}
     cp $SRC_RPM rpmbuild/SRPMS/
-
-    cd rpmbuild/SPECS
-    echo '%undefine _missing_build_ids_terminate_build' | cat - percona-toolkit.spec > pt.spec && mv pt.spec percona-toolkit.spec
-    echo '%define debug_package %{nil}' | cat - percona-toolkit.spec > pt.spec && mv pt.spec percona-toolkit.spec
-    sed -i "s/@@ARHITECTURE@@/x86_64/" percona-toolkit.spec
-    #
     cd $WORKDIR
     RHEL=$(rpm --eval %rhel)
     ARCH=$(echo $(uname -m) | sed -e 's:i686:i386:g')
@@ -432,10 +426,12 @@ build_source_deb(){
     cp *_source.changes $WORKDIR/source_deb
     cp *.dsc $WORKDIR/source_deb
     cp *.orig.tar.gz $WORKDIR/source_deb
+    cp *.diff.gz $WORKDIR/source_deb
    # cp *.tar.xz* $CURDIR/source_deb
     cp *_source.changes $CURDIR/source_deb
     cp *.dsc $CURDIR/source_deb
     cp *.orig.tar.gz $CURDIR/source_deb
+    cp *.diff.gz $CURDIR/source_deb
 }
 
 build_tarball(){
@@ -521,7 +517,23 @@ build_deb(){
     mkdir -p $WORKDIR/deb
     cp $WORKDIR/*.*deb $WORKDIR/deb
     cp $WORKDIR/*.*deb $CURDIR/deb
+    if [ "x$DEBIAN_VERSION" = "xjammy" ]; then
+        for dir in $WORKDIR/deb $CURDIR/deb; do
+	    cd $dir
+            COMP=gzip
+            for i in *.deb; do
+                echo "$i"
+                mkdir "$i.extract"
+                dpkg-deb -R "$i" "$i.extract"
+                rm "$i"
+                dpkg-deb -b "-Z$COMP" "$i.extract" "$i"
+                rm -rf "$i.extract"
+            done
+        done
+    fi
+    cd $WORKDIR
 }
+#===========================
 #main
 export GIT_SSL_NO_VERIFY=1
 CURDIR=$(pwd)
